@@ -6,10 +6,10 @@ from pydantic import BaseModel
 class Request(BaseModel):
     id_: Any
     url: str
-    data: Optional[dict] = {}
+    data: Optional[Any]
 
 
 class Response(BaseModel):
     id_: Any
     status_code: int
-    data: dict
+    data: Any
